@@ -42,7 +42,7 @@ from pgspecial.main import (PGSpecial, NO_QUERY, PAGER_OFF)
 import pgspecial as special
 from .pgcompleter import PGCompleter
 from .pgtoolbar import create_toolbar_tokens_func
-from .pgstyle import style_factory
+from .pgstyle import style_factory, style_factory_output
 from .pgexecute import PGExecute
 from .pgbuffer import PGBuffer
 from .completion_refresher import CompletionRefresher
@@ -83,10 +83,10 @@ MetaQuery.__new__.__defaults__ = ('', False, 0, False, False, False, False)
 
 OutputSettings = namedtuple(
     'OutputSettings',
-    'table_format dcmlfmt floatfmt missingval expanded max_width case_function'
+    'table_format dcmlfmt floatfmt missingval expanded max_width case_function style_output'
 )
 OutputSettings.__new__.__defaults__ = (
-    None, None, None, '<null>', False, None, lambda x: x
+    None, None, None, '<null>', False, None, lambda x: x, None
 )
 
 
@@ -165,6 +165,9 @@ class PGCli(object):
         self.pgspecial.pset_pager(self.config['main'].as_bool(
             'enable_pager') and "on" or "off")
 
+        self.style_output = style_factory_output(
+            self.syntax_style, c['colors'])
+
         self.now = dt.datetime.today()
 
         self.completion_refresher = CompletionRefresher()
@@ -707,7 +710,8 @@ class PGCli(object):
                 case_function=(
                     self.completer.case if self.settings['case_column_headers']
                     else lambda x: x
-                )
+                ),
+                style_output=self.style_output
             )
             formatted = format_output(title, cur, headers, status, settings)
 
@@ -811,7 +815,10 @@ class PGCli(object):
         string = string.replace('\\dsn_alias', self.dsn_alias or '')
         string = string.replace('\\t', self.now.strftime('%x %X'))
         string = string.replace('\\u', self.pgexecute.user or '(none)')
-        string = string.replace('\\h', self.pgexecute.host or '(none)')
+        host = self.pgexecute.host or '(none)'
+        string = string.replace('\\H', host)
+        short_host, _, _ = host.partition('.')
+        string = string.replace('\\h', short_host)
         string = string.replace('\\d', self.pgexecute.dbname or '(none)')
         string = string.replace('\\p', str(self.pgexecute.port) or '(none)')
         string = string.replace('\\i', str(self.pgexecute.pid) or '(none)')
@@ -944,7 +951,7 @@ def cli(database, username_opt, host, port, prompt_passwd, never_prompt,
             missingval='<null>'
         )
         formatted = format_output(title, cur, headers, status, settings)
-        self.echo_via_pager('\n'.join(formatted))
+        pgcli.echo_via_pager('\n'.join(formatted))
 
         sys.exit(0)
 
@@ -1063,7 +1070,8 @@ def format_output(title, cur, headers, status, settings):
         'float_format': settings.floatfmt,
         'preprocessors': (format_numbers, format_arrays),
         'disable_numparse': True,
-        'preserve_whitespace': True
+        'preserve_whitespace': True,
+        'style': settings.style_output
     }
     if not settings.floatfmt:
         output_kwargs['preprocessors'] = (align_decimals, )
